@@ -17,32 +17,46 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Utils.py,v 1.2 1999/08/25 11:07:36 gobry Exp $
+# $Id: Utils.py,v 1.4 1999/09/15 09:29:28 gobry Exp $
 
 from gtk import *
 from gnome.ui import *
 
+from Pyblio import Config
+
+tooltips = GtkTooltips ()
+
+if Config.get ("gnomeui/tooltips").data:
+    tooltips.enable ()
+else:
+    tooltips.disable ()
+
 cursor = {}
 cursor ['clock']  = cursor_new (150)
 cursor ['normal'] = cursor_new (68)
 
 def set_cursor (self, name):
+    if not Config.get ("gnomeui/threads").data: return
+
     self.get_window ().set_cursor (cursor [name])
         
-    # is this normal ??
-    threads_leave ()
+    # not necessary with Gtk+-1.2.5
+    # threads_leave ()
     
     while events_pending ():
         mainiteration (FALSE)
     
-    threads_enter ()
+    # not necessary with Gtk+-1.2.5
+    # threads_enter ()
     return
 
 def popup_add (menu, item, action = None, argument = None):
     """ Helper to add a new menu entry """
+    
     tmp = GtkMenuItem (item)
     if action:
         tmp.connect ("activate", action, argument)
+    
     tmp.show ()
     menu.append (tmp)
     
