@@ -19,12 +19,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographic.py,v 1.4 1999/08/27 12:38:00 gobry Exp $
+# $Id: pybliographic.py,v 1.5 1999/09/02 12:57:50 gobry Exp $
 
 
 from Pyblio.GnomeUI import Pybliographic
 from gtk import *
-from Pyblio import Base
+from Pyblio import Base, Config
+
 import os
 
 main = Pybliographic.Pybliographic (version)
